pub enum SecretsSubCommand {
Show 13 variants
Providers,
List(ListCmd),
Push(PushCmd),
Pull(PullCmd),
GenerateDefault(GenerateDefaultCmd),
GenerateExample(GenerateExampleCmd),
Diff,
Verify,
Diag,
Stores(SecretsStoresCmd),
Secrets(CloudflareSecretsCmd),
Quota(SecretsQuotaCmd),
Usage,
}Variants
Providers
List available secrets providers
List(ListCmd)
List local env vars from the preferred env file
Push(PushCmd)
Push local env vars to the secrets provider (GitHub)
Pull(PullCmd)
Pull secrets from the provider into .env.local
GenerateDefault(GenerateDefaultCmd)
Generate .env.default from source code inspection
GenerateExample(GenerateExampleCmd)
Generate .env.example with categories and defaults
Diff
Compare local env with remote (GitHub) variables
Verify
Verify that all required env vars are available locally
Diag
Check connectivity, token scope, and repo access for secrets
Stores(SecretsStoresCmd)
Manage Cloudflare secrets stores
Secrets(CloudflareSecretsCmd)
Manage Cloudflare secrets in a store
Quota(SecretsQuotaCmd)
Inspect Cloudflare quota usage
Usage
Show secrets command usage