Module commands

Module commands 

command modules aggregation

exposes all cli command implementations and selective re exports for convenient use in the binary entrypoint includes service management redeploy pm2 integration and more

Re-exports

pub use api_control::run_api_daemons;
pub use api_control::run_api_health;
pub use api_control::run_api_jobs;
pub use api_control::run_api_projects;
pub use api_control::run_api_routes;
pub use api_install::install_api_service;
pub use api_request::run_api_request;
pub use cloudflared_access::run_cloudflared_tcp;
pub use cloudflared_access::CloudflaredTcpOptions;
pub use cloudflared_access::CloudflaredTunnel;
pub use commit::run_commit;
pub use commit::CommitArgs;
pub use config_cmd::open_global_config;
pub use config_cmd::run_config;
pub use config_cmd::run_config_cloudflare_account_delete;
pub use config_cmd::run_config_cloudflare_account_set;
pub use config_cmd::run_config_cloudflare_account_show;
pub use config_cmd::run_config_linear_select_initiative;
pub use config_cmd::run_config_publish_setup;
pub use config_cmd::run_config_secret_delete;
pub use config_cmd::run_config_secret_set;
pub use config_cmd::run_config_secret_show;
pub use curl::run_curl;
pub use cursor_ingest::run_cursor_ingest;
pub use deploy::deploy_application;
pub use diag::run_diag;
pub use dns::run_dns;
pub use domains::run_domains;
pub use done::run_done;
pub use fix_process_monitor_json::run_fix_process_monitor_json;
pub use generate_config::run_generate_config;
pub use generate_config::GenerateConfigArgs;
pub use generate_systemd::run_generate_systemd;
pub use generate_systemd::GenerateSystemdArgs;
pub use help::print_help;
pub use init::run_init;
pub use kafka_logs::start_log_shipping;
pub use kafka_logs::tail_kafka_topic;
pub use login::run_login;
pub use logs::parse_logs_args;
pub use logs::view_logs;
pub use monitor::run_single_check;
pub use monitor::start_monitor_daemon;
pub use network::run_network;
pub use nginx::run_nginx;
pub use pm2::pm2_cleanup;
pub use pm2::pm2_delete;
pub use pm2::pm2_env;
pub use pm2::pm2_flush;
pub use pm2::pm2_list;
pub use pm2::pm2_logs;
pub use pm2::pm2_monitor;
pub use pm2::pm2_resurrect;
pub use pm2::pm2_save;
pub use pm2::pm2_snapshot;
pub use pm2::pm2_start;
pub use pm2::pm2_stop;
pub use ports::run_ports;
pub use publish::run_publish_command;
pub use publish::PublishCommandOptions;
pub use redeploy::run_redeploy;
pub use redeploy_service::run_redeploy_service;
pub use service::is_xbp_project;
pub use service::list_services;
pub use service::load_xbp_config;
pub use service::run_service_command;
pub use service::show_service_help;
pub use setup::run_setup;
pub use ssh_session::run_interactive_shell;
pub use ssh_session::InteractiveShellOptions;
pub use start::pm2_start_wrapper;
pub use systemd_unit::build_api_unit_spec;
pub use systemd_unit::create_install_script;
pub use systemd_unit::make_executable;
pub use systemd_unit::render_unit;
pub use systemd_unit::render_unit_and_store;
pub use systemd_unit::unit_file_name;
pub use systemd_unit::write_unit_file;
pub use systemd_unit::RenderedUnit;
pub use systemd_unit::SystemdUnitSpec;
pub use systemd_unit::UnitWriteError;
pub use version::print_version;
pub use version::run_version_command;
pub use version::run_version_release_command;
pub use version::run_version_workspace_command;
pub use version::ReleaseLatestPolicy;
pub use version::VersionReleaseOptions;
pub use version::WorkspacePublishRunOptions;
pub use version::WorkspaceVersionCheckOptions;
pub use version::WorkspaceVersionCommand;
pub use version::WorkspaceVersionCommandOptions;
pub use version::WorkspaceVersionSyncOptions;
pub use version::WorkspaceVersionValidateOptions;
pub use workers::run_workers;
pub use install::*;

Modules

api_control
api_install
api_request
cli_session
cloudflared_access
commit
config_cmd
config command module
curl
cursor_ingest
deploy
Advanced deployment command module
diag
dns
domains
done
“What did I get done” — generate a Markdown report of your git commits across repos.
fix_process_monitor_json
generate_config
Project config generation and migration helpers.
generate_systemd
help
custom help renderer
init
Init command module
install
Package installation module for xbp
kafka_logs
linear
login
logs
Logs command module for viewing XBP logs
monitor
network
nginx
pm2
pm2 process management module
ports
ports command module
publish
redeploy
local redeploy command module
redeploy_service
redeploy service module
redeploy_v2
Remote redeploy via SSH
service
service command module
setup
Setup command module
ssh_helpers
ssh_logs
ssh_session
start
system_diag
system_inventory_refresh
systemd_unit
version
Version management commands and adapters.
workers