Module linear_cmd

Module linear_cmd 

User-facing Linear issue management (xbp linear).

Structs

CreateIssueInput
LinearComment
LinearIssue
LinearLabel
LinearProject
LinearTeam
LinearUser
LinearWorkflowState
ListIssuesFilter
UpdateIssueInput

Enums

IssueSortField

Constants

LINEAR_API_KEYS_URL
Linear personal API key settings page.

Functions

archive_issue
Archive a Linear issue by id or identifier.
attachment_link_url
Attach an external URL to a Linear issue (generic link attachment).
create_comment
create_issue
default_team_hint
ensure_label_ids
Resolve label ids, creating missing labels on the team when possible.
ensure_linear_api_key
Resolve a Linear API key from local config, dashboard, or interactive setup.
get_issue
issues_for_attachment_url
Look up Linear issues that have an attachment pointing at url (e.g. a GitHub issue URL).
list_comments
list_issues
list_labels
list_projects
list_teams
list_users
list_workflow_states
mark_duplicate_of
Mark duplicate as a duplicate of canonical (both id or identifier).
prompt_and_save_default_team
Interactive team picker that persists linear.default_team_key (and id) on the project.
resolve_assignee_id
resolve_project_id
resolve_team_id
resolve_team_id_auto
Prefer configured team, else the only accessible team, else error.
run_linear
sort_issues
update_issue