Module config

Module config 

configuration management module

handles ssh configuration and yaml config file management provides loading and saving of configuration files supports home directory based config storage

Structs

ApiConfig
Simple API configuration for the XBP version endpoints.
CliAuthState
CursorIngestState
DeviceIdentity
GlobalXbpPaths
LinearConfig
LinearReleaseConfig
OpenRouterConfig
PackageNameFilesConfig
PackageNameLookup
SecretMetadata
SshConfig
SystemInventoryRefreshState
SystemInventorySyncResult
VersioningFilesConfig

Enums

SecretProvider

Functions

describe_global_xbp_paths
ensure_global_xbp_paths
get_cloudflare_account_id
get_config_path
global_xbp_paths
load_package_name_files_registry
load_versioning_files_registry
record_cursor_ingest_failure
record_cursor_ingest_started
record_cursor_ingest_success
record_system_inventory_refresh_failure
record_system_inventory_refresh_started
record_system_inventory_refresh_success
reserve_cursor_ingest_slot
reserve_system_inventory_refresh_slot
resolve_cloudflare_account_id
resolve_cloudflare_api_token
resolve_crates_token
resolve_device_identity
resolve_github_oauth2_key
resolve_global_linear_release_config
resolve_linear_api_key
resolve_npm_token
resolve_openrouter_api_key
resolve_openrouter_commit_model
resolve_openrouter_commit_system_prompt
resolve_openrouter_release_notes_model
resolve_openrouter_release_notes_system_prompt
resolve_xbp_api_token
set_cloudflare_account_id
sync_package_name_files_registry
sync_system_inventory
sync_versioning_files_registry
update_dns_inventory_cache