Module logging

Module logging 

comprehensive logging system for xbp

provides structured logging to /var/log/xbp/ with automatic log rotation different log levels and command specific log files supports async logging with per command tracing and file based storage

Structs

LogEntry
XbpLogger

Enums

LogLevel

Functions

get_log_directory
Get the log directory path
get_logger
Get a cloned reference to the logger for use in async contexts
get_prefix
Helper function to get the standardized log prefix
get_project_name
Helper function to get the current project name from the logger
init_logger
Initialize the global logger
log_debug
Helper function to log debug with the global logger
log_error
Helper function to log errors with the global logger
log_file_only
log_info
Helper function to log info with the global logger
log_process_output
Helper function to log process output with the global logger
log_process_output_file_only
log_success
Helper function to log success with the global logger
log_timed
Helper function to log timed events with the global logger
log_warn
Helper function to log warnings with the global logger
with_logger
Execute a closure with the global logger if it exists