User-facing Linear issue management (xbp linear).
Structs
- Create
Issue Input - Linear
Comment - Linear
Issue - Linear
Label - Linear
Project - Linear
Team - Linear
User - Linear
Workflow State - List
Issues Filter - Update
Issue Input
Enums
Constants
- LINEAR_
API_ KEYS_ URL - Linear personal API key settings page.
Functions
- archive_
issue - Archive a Linear issue by id or identifier.
- attachment_
link_ url - Attach an external URL to a Linear issue (generic link attachment).
- create_
comment - create_
issue - default_
team_ hint - ensure_
label_ ids - Resolve label ids, creating missing labels on the team when possible.
- ensure_
linear_ api_ key - Resolve a Linear API key from local config, dashboard, or interactive setup.
- get_
issue - issues_
for_ attachment_ url - Look up Linear issues that have an attachment pointing at
url(e.g. a GitHub issue URL). - list_
comments - list_
issues - list_
labels - list_
projects - list_
teams - list_
users - list_
workflow_ states - mark_
duplicate_ of - Mark
duplicateas a duplicate ofcanonical(both id or identifier). - prompt_
and_ save_ default_ team - Interactive team picker that persists
linear.default_team_key(and id) on the project. - resolve_
assignee_ id - resolve_
project_ id - resolve_
team_ id - resolve_
team_ id_ auto - Prefer configured team, else the only accessible team, else error.
- run_
linear - sort_
issues - update_
issue