comprehensive logging system for xbp
provides structured logging to /var/log/xbp/ with automatic log rotation different log levels and command specific log files supports async logging with per command tracing and file based storage
Structs
Enums
Functions
- get_
log_ directory - Get the log directory path
- get_
logger - Get a cloned reference to the logger for use in async contexts
- get_
prefix - Helper function to get the standardized log prefix
- get_
project_ name - Helper function to get the current project name from the logger
- init_
logger - Initialize the global logger
- log_
debug - Helper function to log debug with the global logger
- log_
error - Helper function to log errors with the global logger
- log_
info - Helper function to log info with the global logger
- log_
process_ output - Helper function to log process output with the global logger
- log_
success - Helper function to log success with the global logger
- log_
timed - Helper function to log timed events with the global logger
- log_
warn - Helper function to log warnings with the global logger
- with_
logger - Execute a closure with the global logger if it exists